pub struct ParsecToolApp {
pub provider: Option<u8>,
pub timeout: Option<u32>,
pub subcommand: Subcommand,
}Expand description
Struct representing the command-line interface of parsec-tool.
Fields
provider: Option<u8>The ID of the provider to target for the command. Will use the default provider if not specified.
timeout: Option<u32>The timeout time used for all commands in seconds. Will use the client’s default if not specified. If set to 0, will not use any timeout and will block indefinitely.
subcommand: SubcommandThe subcommand – e.g., ping.